@@ -1,5 +1,5 @@
 package DateTime::TimeZone::Local::Win32;
-$DateTime::TimeZone::Local::Win32::VERSION = '1.88';
+$DateTime::TimeZone::Local::Win32::VERSION = '1.89';
 use 5.006;
 
 use strict;
@@ -22,6 +22,7 @@ sub EnvVars { return 'TZ' }
         'Afghanistan Standard Time'       => 'Asia/Kabul',
         'Alaskan'                         => 'America/Anchorage',
         'Alaskan Standard Time'           => 'America/Anchorage',
+        'Aleutian Standard Time'          => 'America/Adak',
         'Altai Standard Time'             => 'Asia/Barnaul',
         'Arab'                            => 'Asia/Riyadh',
         'Arab Standard Time'              => 'Asia/Riyadh',
@@ -35,6 +36,7 @@ sub EnvVars { return 'TZ' }
         'Atlantic Standard Time'          => 'America/Halifax',
         'AUS Central'                     => 'Australia/Darwin',
         'AUS Central Standard Time'       => 'Australia/Darwin',
+        'Aus Central W. Standard Time'    => 'Australia/Eucla',
         'AUS Eastern'                     => 'Australia/Sydney',
         'AUS Eastern Standard Time'       => 'Australia/Sydney',
         'Azerbaijan Standard Time'        => 'Asia/Baku',
@@ -46,6 +48,7 @@ sub EnvVars { return 'TZ' }
         'Bangladesh Standard Time'        => 'Asia/Dhaka',
         'Beijing'                         => 'Asia/Shanghai',
         'Belarus Standard Time'           => 'Europe/Minsk',
+        'Bougainville Standard Time'      => 'Pacific/Bougainville',
         'Canada Central'                  => 'America/Regina',
         'Canada Central Standard Time'    => 'America/Regina',
         'Cape Verde Standard Time'        => 'Atlantic/Cape_Verde',
@@ -66,8 +69,10 @@ sub EnvVars { return 'TZ' }
         'Central Pacific Standard Time'   => 'Pacific/Guadalcanal',
         'Central Standard Time'           => 'America/Chicago',
         'Central Standard Time (Mexico)'  => 'America/Mexico_City',
+        'Chatham Islands Standard Time'   => 'Pacific/Chatham',
         'China'                           => 'Asia/Shanghai',
         'China Standard Time'             => 'Asia/Shanghai',
+        'Cuba Standard Time'              => 'America/Havana',
         'Dateline'                        => '-1200',
         'Dateline Standard Time'          => '-1200',
         'E. Africa'                       => 'Africa/Nairobi',
@@ -78,6 +83,7 @@ sub EnvVars { return 'TZ' }
         'E. Europe Standard Time'         => 'Europe/Helsinki',
         'E. South America'                => 'America/Sao_Paulo',
         'E. South America Standard Time'  => 'America/Sao_Paulo',
+        'Easter Island Standard Time'     => 'Pacific/Easter',
         'Eastern'                         => 'America/New_York',
         'Eastern Standard Time'           => 'America/New_York',
         'Eastern Standard Time (Mexico)'  => 'America/Cancun',
@@ -99,6 +105,7 @@ sub EnvVars { return 'TZ' }
         'Greenwich Standard Time'         => 'GMT',
         'GTB'                             => 'Europe/Athens',
         'GTB Standard Time'               => 'Europe/Athens',
+        'Haiti Standard Time'             => 'America/Port_au_Prince',
         'Hawaiian'                        => 'Pacific/Honolulu',
         'Hawaiian Standard Time'          => 'Pacific/Honolulu',
         'India'                           => 'Asia/Calcutta',
@@ -114,7 +121,9 @@ sub EnvVars { return 'TZ' }
         'Korea Standard Time'             => 'Asia/Seoul',
         'Libya Standard Time'             => 'Africa/Tripoli',
         'Line Islands Standard Time'      => 'Pacific/Kiritimati',
+        'Lord Howe Standard Time'         => 'Australia/Lord_Howe',
         'Magadan Standard Time'           => 'Asia/Magadan',
+        'Marquesas Standard Time'         => 'Pacific/Marquesas',
         'Mauritius Standard Time'         => 'Indian/Mauritius',
         'Mexico'                          => 'America/Mexico_City',
         'Mexico Standard Time'            => 'America/Mexico_City',
@@ -135,6 +144,7 @@ sub EnvVars { return 'TZ' }
         'New Zealand Standard Time'       => 'Pacific/Auckland',
         'Newfoundland'                    => 'America/St_Johns',
         'Newfoundland Standard Time'      => 'America/St_Johns',
+        'Norfolk Standard Time'           => 'Pacific/Norfolk',
         'North Asia East Standard Time'   => 'Asia/Irkutsk',
         'North Asia Standard Time'        => 'Asia/Krasnoyarsk',
         'North Korea Standard Time'       => 'Asia/Pyongyang',
@@ -159,6 +169,7 @@ sub EnvVars { return 'TZ' }
         'SA Pacific Standard Time'        => 'America/Bogota',
         'SA Western'                      => 'America/Guyana',
         'SA Western Standard Time'        => 'America/Guyana',
+        'Saint Pierre Standard Time'      => 'America/Miquelon',
         'Sakhalin Standard Time'          => 'Asia/Sakhalin',
         'Samoa'                           => 'Pacific/Apia',
         'Samoa Standard Time'             => 'Pacific/Apia',
@@ -178,11 +189,14 @@ sub EnvVars { return 'TZ' }
         'Taipei Standard Time'            => 'Asia/Taipei',
         'Tasmania'                        => 'Australia/Hobart',
         'Tasmania Standard Time'          => 'Australia/Hobart',
+        'Tocantins Standard Time'         => 'America/Araguaina',
         'Tokyo'                           => 'Asia/Tokyo',
         'Tokyo Standard Time'             => 'Asia/Tokyo',
+        'Tomsk Standard Time'             => 'Asia/Tomsk',
         'Tonga Standard Time'             => 'Pacific/Tongatapu',
         'Transbaikal Standard Time'       => 'Asia/Chita',
         'Turkey Standard Time'            => 'Europe/Istanbul',
+        'Turks And Caicos Standard Time'  => 'America/Grand_Turk',
         'Ulaanbaatar Standard Time'       => 'Asia/Ulaanbaatar',
         'US Eastern'                      => 'America/Indianapolis',
         'US Eastern Standard Time'        => 'America/Indianapolis',
@@ -191,6 +205,8 @@ sub EnvVars { return 'TZ' }
         'UTC'                             => 'UTC',
         'UTC+12'                          => '+1200',
         'UTC-02'                          => '-0200',
+        'UTC-08'                          => '-0800',
+        'UTC-09'                          => '-0900',
         'UTC-11'                          => '-1100',
         'Venezuela Standard Time'         => 'America/Caracas',
         'Vladivostok'                     => 'Asia/Vladivostok',
@@ -200,9 +216,11 @@ sub EnvVars { return 'TZ' }
         'W. Central Africa Standard Time' => 'Africa/Luanda',
         'W. Europe'                       => 'Europe/Berlin',
         'W. Europe Standard Time'         => 'Europe/Berlin',
+        'W. Mongolia Standard Time'       => 'Asia/Hovd',
         'Warsaw'                          => 'Europe/Warsaw',
         'West Asia'                       => 'Asia/Karachi',
         'West Asia Standard Time'         => 'Asia/Karachi',
+        'West Bank Standard Time'         => 'Asia/Gaza',
         'West Pacific'                    => 'Pacific/Guam',
         'West Pacific Standard Time'      => 'Pacific/Guam',
         'Western Brazilian Standard Time' => 'America/Rio_Branco',
@@ -295,7 +313,7 @@ DateTime::TimeZone::Local::Win32 - Determine the local system's time zone on Win
 
 =head1 VERSION
 
-version 1.88
+version 1.89
 
 =head1 SYNOPSIS
 
@@ -362,7 +380,7 @@ of "SOFTWARE/Microsoft/Windows/CurrentVersion/Time Zones/"
 
 =item *
 
-David Pinkowitz <dapink@cpan.org>
+David Pinkowitz <david_pinkowitz@bmc.com>
 
 =item *
 
@@ -373,7 +391,7 @@ Dave Rolsky <autarch@urth.org>
 =head1 COPYRIGHT AND LICENSE
 
 Copyright (C) 2007-2014 Dave Rolsky <autarch@urth.org>
-Copyright (C) 2014-2016 by David Pinkowitz <dapink@cpan.org>
+Copyright (C) 2014-2016 by David Pinkowitz <david_pinkowitz@bmc.com>
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
